@@ -1,9 +1,9 @@
 #
-# $Id: Encode.pm,v 1.63 2002/04/27 18:59:50 dankogai Exp $
+# $Id: Encode.pm,v 1.64 2002/04/29 06:54:06 dankogai Exp $
 #
 package Encode;
 use strict;
-our $VERSION = do { my @r = (q$Revision: 1.63 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.64 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 our $DEBUG = 0;
 use XSLoader ();
 XSLoader::load(__PACKAGE__, $VERSION);
@@ -18,9 +18,9 @@ our @EXPORT = qw(
   encodings  find_encoding
 );
 
-our @FB_FLAGS  = qw(DIE_ON_ERR WARN_ON_ERR RETURN_ON_ERR LEAVE_SRC 
+our @FB_FLAGS  = qw(DIE_ON_ERR WARN_ON_ERR RETURN_ON_ERR LEAVE_SRC
 		    PERLQQ HTMLCREF XMLCREF);
-our @FB_CONSTS = qw(FB_DEFAULT FB_CROAK FB_QUIET FB_WARN 
+our @FB_CONSTS = qw(FB_DEFAULT FB_CROAK FB_QUIET FB_WARN
 		    FB_PERLQQ FB_HTMLCREF FB_XMLCREF);
 
 our @EXPORT_OK =
@@ -258,7 +258,7 @@ sub predefine_encodings{
 	    $_[1] = '' if $chk;
 	    return $octets;
 	};
-	$Encode::Encoding{utf8} = 
+	$Encode::Encoding{utf8} =
 	    bless {Name => "utf8"} => "Encode::utf8";
     }
 }
@@ -339,33 +339,29 @@ I<octet>: 8 bits of data, with ordinal values 0..255
 
 =back
 
-The marker [INTERNAL] marks Internal Implementation Details, in
-general meant only for those who think they know what they are doing,
-and such details may change in future releases.
-
 =head1 PERL ENCODING API
 
 =over 2
 
-=item $octets  = encode(ENCODING, $string[, CHECK])
+=item $octets  = encode(ENCODING, $string [, CHECK])
 
 Encodes a string from Perl's internal form into I<ENCODING> and returns
 a sequence of octets.  ENCODING can be either a canonical name or
 an alias.  For encoding names and aliases, see L</"Defining Aliases">.
 For CHECK, see L</"Handling Malformed Data">.
 
-For example, to convert (internally UTF-8 encoded) Unicode string to
+For example, to convert a string from Perl's internal format to
 iso-8859-1 (also known as Latin1),
 
-  $octets = encode("iso-8859-1", $utf8);
+  $octets = encode("iso-8859-1", $string);
 
-B<CAVEAT>: When you C<$octets = encode("utf8", $utf8)>, then $octets
-B<ne> $utf8.  Though they both contain the same data, the utf8 flag
+B<CAVEAT>: When you run C<$octets = encode("utf8", $string)>, then $octets
+B<may not be equal to> $string.  Though they both contain the same data, the utf8 flag
 for $octets is B<always> off.  When you encode anything, utf8 flag of
 the result is always off, even when it contains completely valid utf8
 string. See L</"The UTF-8 flag"> below.
 
-=item $string = decode(ENCODING, $octets[, CHECK])
+=item $string = decode(ENCODING, $octets [, CHECK])
 
 Decodes a sequence of octets assumed to be in I<ENCODING> into Perl's
 internal form and returns the resulting string.  As in encode(),
@@ -373,39 +369,40 @@ ENCODING can be either a canonical name or an alias. For encoding names
 and aliases, see L</"Defining Aliases">.  For CHECK, see
 L</"Handling Malformed Data">.
 
-For example, to convert ISO-8859-1 data to UTF-8:
+For example, to convert ISO-8859-1 data to a string in Perl's internal format:
 
-  $utf8 = decode("iso-8859-1", $latin1);
+  $string = decode("iso-8859-1", $octets);
 
-B<CAVEAT>: When you C<$utf8 = encode("utf8", $octets)>, then $utf8
-B<may not be equal to> $utf8.  Though they both contain the same data,
-the utf8 flag for $utf8 is on unless $octets entirely conststs of
+B<CAVEAT>: When you run C<$string = decode("utf8", $octets)>, then $string
+B<may not be equal to> $octets.  Though they both contain the same data,
+the utf8 flag for $string is on unless $octets entirely consists of
 ASCII data (or EBCDIC on EBCDIC machines).  See L</"The UTF-8 flag">
 below.
 
-=item [$length =] from_to($string, FROM_ENC, TO_ENC [, CHECK])
+=item [$length =] from_to($octets, FROM_ENC, TO_ENC [, CHECK])
 
-Converts B<in-place> data between two encodings. For example, to
-convert ISO-8859-1 data to UTF-8:
+Converts B<in-place> data between two encodings. The data in $octets
+must be encoded as octets and not as characters in Perl's internal
+format. For example, to convert ISO-8859-1 data to Microsoft's CP1250 encoding:
 
-  from_to($data, "iso-8859-1", "utf8");
+  from_to($octets, "iso-8859-1", "cp1250");
 
 and to convert it back:
 
-  from_to($data, "utf8", "iso-8859-1");
+  from_to($octets, "cp1250", "iso-8859-1");
 
 Note that because the conversion happens in place, the data to be
 converted cannot be a string constant; it must be a scalar variable.
 
-from_to() returns the length of the converted string on success, undef
+from_to() returns the length of the converted string in octets on success, undef
 otherwise.
 
-B<CAVEAT>: The following operations look the same but not quite so;
+B<CAVEAT>: The following operations look the same but are not quite so;
 
-  from_to($data, "iso-8859-1", "utf8"); #1 
+  from_to($data, "iso-8859-1", "utf8"); #1
   $data = decode("iso-8859-1", $data);  #2
 
-Both #1 and #2 makes $data consists of completely valid UTF-8 string
+Both #1 and #2 make $data consist of a completely valid UTF-8 string
 but only #2 turns utf8 flag on.  #1 is equivalent to
 
   $data = encode("utf8", decode("iso-8859-1", $data));
@@ -415,15 +412,15 @@ See L</"The UTF-8 flag"> below.
 =item $octets = encode_utf8($string);
 
 Equivalent to C<$octets = encode("utf8", $string);> The characters
-that comprise $string are encoded in Perl's superset of UTF-8 and the
-resulting octets are returned as a sequence of bytes. All possible
+that comprise $string are encoded in Perl's internal format and the
+result is returned as a sequence of octets. All possible
 characters have a UTF-8 representation so this function cannot fail.
 
 
 =item $string = decode_utf8($octets [, CHECK]);
 
 equivalent to C<$string = decode("utf8", $octets [, CHECK])>.
-decode_utf8($octets [, CHECK]); The sequence of octets represented by
+The sequence of octets represented by
 $octets is decoded from UTF-8 into a sequence of logical
 characters. Not all sequences of octets form valid UTF-8 encodings, so
 it is possible for this call to fail.  For CHECK, see
@@ -480,23 +477,24 @@ See L<Encode::Alias> for details.
 
 =head1 Encoding via PerlIO
 
-If your perl supports I<PerlIO>, you can use a PerlIO layer to decode
+If your perl supports I<PerlIO> (which is the default), you can use a PerlIO layer to decode
 and encode directly via a filehandle.  The following two examples
 are totally identical in their functionality.
 
   # via PerlIO
   open my $in,  "<:encoding(shiftjis)", $infile  or die;
   open my $out, ">:encoding(euc-jp)",   $outfile or die;
-  while(<>){ print; }
+  while(<$in>){ print $out $_; }
 
   # via from_to
   open my $in,  "<", $infile  or die;
   open my $out, ">", $outfile or die;
-  while(<>){
+  while(<$in>){
     from_to($_, "shiftjis", "euc-jp", 1);
+    print $out $_;
   }
 
-Unfortunately, there may be encodings are PerlIO-savvy.  You can check
+Unfortunately, it may be that encodings are PerlIO-savvy.  You can check
 if your encoding is supported by PerlIO by calling the C<perlio_ok>
 method.
 
@@ -507,9 +505,7 @@ method.
   perlio_ok("euc-jp")
 
 Fortunately, all encodings that come with Encode core are PerlIO-savvy
-except for hz and ISO-2022-kr.  See L<Encode::Encoding> for details.
-
-For gory details, see L<Encode::PerlIO>.
+except for hz and ISO-2022-kr.  For gory details, see L<Encode::Encoding> and L<Encode::PerlIO>.
 
 =head1 Handling Malformed Data
 
@@ -523,13 +519,13 @@ I<CHECK>.
 
 If I<CHECK> is 0, (en|de)code will put a I<substitution character>
 in place of a malformed character.  For UCM-based encodings,
-E<lt>subcharE<gt> will be used.  For Unicode, "\x{FFFD}" is used.
+E<lt>subcharE<gt> will be used.  For Unicode, the code point C<0xFFFD> is used.
 If the data is supposed to be UTF-8, an optional lexical warning
 (category utf8) is given.
 
 =item I<CHECK> = Encode::FB_CROAK ( == 1)
 
-If I<CHECK> is 1, methods will die immediately with an error
+If I<CHECK> is 1, methods will die on error immediately with an error
 message.  Therefore, when I<CHECK> is set to 1,  you should trap the
 fatal error with eval{} unless you really want to let it die on error.
 
@@ -544,7 +540,7 @@ where your source data may contain partial multi-byte character
 sequences, for example because you are reading with a fixed-width
 buffer. Here is some sample code that does exactly this:
 
-  my $data = '';
+  my $data = ''; my $utf8 = '';
   while(defined(read $fh, $buffer, 256)){
     # buffer may end in a partial character so we append
     $data .= $buffer;
@@ -566,15 +562,15 @@ you are debugging the mode above.
 For encodings that are implemented by Encode::XS, CHECK ==
 Encode::FB_PERLQQ turns (en|de)code into C<perlqq> fallback mode.
 
-When you decode, '\xI<XX>' will be inserted for a malformed character,
-where I<XX> is the hex representation of the octet  that could not be
-decoded to utf8.  And when you encode, '\x{I<xxxx>}' will be inserted,
-where I<xxxx> is the Unicode ID of the character that cannot be found
+When you decode, C<\xI<HH>> will be inserted for a malformed character,
+where I<HH> is the hex representation of the octet  that could not be
+decoded to utf8.  And when you encode, C<\x{I<HHHH>}> will be inserted,
+where I<HHHH> is the Unicode ID of the character that cannot be found
 in the character repertoire of the encoding.
 
 HTML/XML character reference modes are about the same, in place of
-\x{I<xxxx>}, HTML uses &#I<1234>; where I<1234> is a decimal digit and
-XML uses &#xI<abcd>; where I<abcd> is the hexadecimal digit.
+C<\x{I<HHHH>}>, HTML uses C<&#I<NNNN>>; where I<NNNN> is a decimal digit and
+XML uses C<&#xI<HHHH>>; where I<HHHH> is the hexadecimal digit.
 
 =item The bitmask
 
@@ -589,8 +585,8 @@ constants via C<use Encode qw(:fallback_all)>.
  RETURN_ON_ERR 0x0004                      X        X
  LEAVE_SRC     0x0008
  PERLQQ        0x0100                                        X
- HTMLCREF      0x0200                                         
- XMLCREF       0x0400                                          
+ HTMLCREF      0x0200
+ XMLCREF       0x0400
 
 =head2 Unimplemented fallback schemes
 
@@ -601,22 +597,23 @@ function for the value of I<CHECK> but its API is still undecided.
 
 To define a new encoding, use:
 
-    use Encode qw(define_alias);
+    use Encode qw(define_encoding);
     define_encoding($object, 'canonicalName' [, alias...]);
 
 I<canonicalName> will be associated with I<$object>.  The object
 should provide the interface described in L<Encode::Encoding>.
 If more than two arguments are provided then additional
-arguments are taken as aliases for I<$object>, as for C<define_alias>.
+arguments are taken as aliases for I<$object>.
 
 See L<Encode::Encoding> for more details.
 
 =head1 The UTF-8 flag
 
 Before the introduction of utf8 support in perl, The C<eq> operator
-just compares internal data of the scalars.  Now C<eq> means internal
-data equality AND I<the utf8 flag>.  To explain why we made it so, I
-will quote page 402 of C<Programming Perl, 3rd ed.>
+just compared the strings represented by two scalars. Beginning with
+perl 5.8, C<eq> compares two strings with simultaneous consideration
+of I<the utf8 flag>. To explain why we made it so, I will quote page
+402 of C<Programming Perl, 3rd ed.>
 
 =over 2
 
@@ -644,9 +641,9 @@ byte-oriented Perl and a character-oriented Perl.
 
 Back when C<Programming Perl, 3rd ed.> was written, not even Perl 5.6.0
 was born and many features documented in the book remained
-unimplemented.  Perl 5.8 hopefully correct this and the introduction
-of UTF-8 flag is one of them.  You can think this perl notion of
-byte-oriented mode (utf8 flag off) and character-oriented mode (utf8
+unimplemented for a long time.  Perl 5.8 corrected this and the introduction
+of the UTF-8 flag is one of them.  You can think of this perl notion as of a
+byte-oriented mode (utf8 flag off) and a character-oriented mode (utf8
 flag on).
 
 Here is how Encode takes care of the utf8 flag.
@@ -659,11 +656,11 @@ When you encode, the resulting utf8 flag is always off.
 
 =item
 
-When you decode, the resuting utf8 flag is on unless you can
+When you decode, the resulting utf8 flag is on unless you can
 unambiguously represent data.  Here is the definition of
 dis-ambiguity.
 
-  After C<$utf8 = decode('foo', $octet);>, 
+After C<$utf8 = decode('foo', $octet);>,
 
   When $octet is...   The utf8 flag in $utf8 is
   ---------------------------------------------
@@ -730,6 +727,6 @@ the Perl Unicode Mailing List E<lt>perl-unicode@perl.orgE<gt>
 This project was originated by Nick Ing-Simmons and later maintained
 by Dan Kogai E<lt>dankogai@dan.co.jpE<gt>.  See AUTHORS for a full
 list of people involved.  For any questions, use
-E<lt>perl-unicode@perl.orgE<gt> so we can all share share.
+E<lt>perl-unicode@perl.orgE<gt> so we can all share.
 
 =cut
